# Hub scraper

Tool to grab articles from the habr.com hubs.

## Requirements
- Python 3.8+

## Installation
```bash
pip install hub-scraper
```


## Usage
```bash
hub-scraper --help

hub-scraper -h python -of /home/user/Downloads/hubs
```

I'm using [Obsidian](https://obsidian.md/) to view the articles:
![](https://github.com/dmitriiweb/hub-scraper/raw/main/images/default-obsidian.png)